@@ -1,5 +1,5 @@
 package ETL::Yertl::Command::ysql;
-our $VERSION = '0.030';
+our $VERSION = '0.031';
 # ABSTRACT: Read and write documents with a SQL database
 
 use ETL::Yertl;
@@ -35,6 +35,7 @@ sub main {
         'save=s',
         'edit|e=s',
         'select=s',
+        'count=s',
         'insert=s',
         'delete=s',
         'where=s',
@@ -210,6 +211,9 @@ sub main {
         if ( $opt{select} ) {
             $query = $sql->select( $opt{select}, '*', $opt{where}, $opt{order} );
         }
+        elsif ( $opt{count} ) {
+            $query = $sql->select( $opt{count}, 'COUNT(*) AS value', $opt{where} );
+        }
         elsif ( $opt{delete} ) {
             $query = $sql->delete( $opt{delete}, $opt{where} );
         }
@@ -327,7 +331,7 @@ ETL::Yertl::Command::ysql - Read and write documents with a SQL database
 
 =head1 VERSION
 
-version 0.030
+version 0.031
 
 =head1 AUTHOR
 
